@@ -5,6 +5,7 @@ use warnings;
 use Keyword::Declare;
 use Data::Dumper;   # DEBUG
 use Carp qw(croak);
+use Scalar::Util qw(looks_like_number);
 
 use vars;
 use Import::Into;
@@ -124,23 +125,49 @@ sub import {
     #print STDERR "$self import into $target\n";
     #_printtrace();
 
-    # Get out of Test::Kit if we're in there, since Test::Kit doesn't know how
-    # to copy the keyword from its fake package to the ultimate caller.
-    ($target, $level) = _escapekit($1) if $target =~ m{^Test::Kit::Fake::(.*)::\Q$self\E$};
-    #print STDERR "$self real target = $target at level $level\n";
+    # Special-case imports from Test::Kit, since Test::Kit doesn't know how
+    # to copy the custom keyword from its fake package to the ultimate caller.
+    if($target =~ m{^Test::Kit::Fake::(.*)::\Q$self\E$}) {
+        ($target, $level) = _escapekit($1);
+        #print STDERR "$self real target = $target at level $level\n";
+        $self->import::into($target);   # Import into the real target
+        return;     # *** EXIT POINT ***
+    }
 
-    # Copy symbols listed in @EXPORT first, in case @_ gets trashed later.
-    $self->export_to_level($level, @_);
+    # Sanity check - e.g., `perl -MTest::OnlySome -E `os ok(1);` will
+    # die because skip() isn't defined.  However, we don't require
+    # Test::More because there might be other packages that you are
+    # using that provide skip().
+    {
+        no strict 'refs';
+        croak "Test::OnlySome: ${target}::skip() not defined - I can't function!  (Missing `use Test::More`?)"
+            unless (defined &{ $target . '::skip' });
+    }
+
+    # Copy symbols listed in @EXPORT first.  Ignore @_, which we are
+    # going to use for our own purposes below.
+    $self->export_to_level($level);
 
     # Create the variables we need in the target package
     vars->import::into($target, qw($TEST_NUMBER_OS $TEST_ONLYSOME));
 
-    do {
+    # Initialize the variables unless they already have been
+    my $hrTOS;
+    {
         no strict 'refs';
-        ${ $target . '::TEST_NUMBER_OS' } = 1;    # tests start at 1, not 0
-        ${ $target . '::TEST_ONLYSOME' } = {};
+        ${ $target . '::TEST_NUMBER_OS' } = 1       # tests start at 1, not 0
+            unless ${ $target . '::TEST_NUMBER_OS' };
+        ${ $target . '::TEST_ONLYSOME' } = {}
+            unless 'HASH' eq ref ${ $target . '::TEST_ONLYSOME' };
+        $hrTOS = ${ $target . '::TEST_ONLYSOME' };
     };
 
+    # Check the arguments.  Numeric arguments are tests to skip.
+    foreach(@_) {
+        $hrTOS->{skip}->{$_} = true
+            if(!ref && looks_like_number $_);
+    }
+
 # `os` keyword - mark each test-calling statement this way {{{2
 
 =head2 os
@@ -179,7 +206,6 @@ not in the caller's scope.
         }
 
         # Get the options
-        #my $hrOptsName = $opts_name || ('$' . $target . '::TEST_ONLYSOME');
         my $hrOptsName = $opts_name || '$TEST_ONLYSOME';
 
 #        print STDERR "os: Options in $hrOptsName\n";
@@ -193,6 +219,8 @@ not in the caller's scope.
 
 } # import()
 
+# Unimport {{{2
+
 =head2 unimport
 
 Removes the L</os> keyword definition.
@@ -203,50 +231,12 @@ sub unimport {
     unkeyword os;
 }
 
+# }}}2
 # }}}1
 # Implementation of keywords (macro), and internal helpers {{{1
 
 =head1 INTERNALS
 
-=head2 _escapekit
-
-Find the caller using a Test::Kit package that uses us, so we can import
-the keyword the right place.
-
-=cut
-
-sub _escapekit {
-# Find the real target package, in case we were called from Test::Kit
-    my $kit = shift;
-    #print STDERR "Invoked from Test::Kit module $kit\n";
-
-    my $level;
-
-    #       0         1          2      3            4
-    my ($callpkg, $filename, $line, $subroutine, $hasargs,
-    #    5          6          7            8       9         10
-    $wantarray, $evaltext, $is_require, $hints, $bitmask, $hinthash);
-
-    # Find the caller of $kit, and import directly there.
-    for($level=0; 1; ++$level) {
-        #       0         1          2      3            4
-        ($callpkg, $filename, $line, $subroutine, $hasargs,
-        #    5          6          7            8       9         10
-        $wantarray, $evaltext, $is_require, $hints, $bitmask, $hinthash)
-        = caller($level);
-        last unless $callpkg;
-        last if $callpkg eq $kit;
-    } #for levels
-
-    if($callpkg && ($callpkg eq $kit)) {
-        ++$level;
-        $callpkg = caller($level);
-        return ($callpkg, $level) if $callpkg;
-    }
-
-    die "Could not find the module that invoked Test::Kit module $kit";
-} #_escapekit()
-
 =head2 _gen
 
 This routine generates source code that, at runtime, will execute a given
@@ -266,7 +256,7 @@ sub _gen {
     my $R = '}';
 
     my $replacement = qq{
-        do {
+        {
             my \$ntests = $optsVarName$W$L n $R // 1;   # TODO move this to a separate parm of os()
             my \$first_test_num = \$TEST_NUMBER_OS;
             \$TEST_NUMBER_OS += \$ntests;
@@ -284,6 +274,8 @@ sub _gen {
 
 } #_gen()
 
+# `os`, skip*() helpers {{{2
+
 =head2 _opts
 
 Returns the appropriate options hashref.  Call as C<_opts($_[0])>.
@@ -316,6 +308,41 @@ sub _nexttestnum {
     return do { no strict 'refs'; ${ "$target" . '::TEST_NUMBER_OS' } };
 } #_nexttestnum()
 
+# }}}2
+# `use` helpers {{{2
+
+=head2 _escapekit
+
+Find the caller using a Test::Kit package that uses us, so we can import
+the keyword the right place.
+
+=cut
+
+sub _escapekit {
+# Find the real target package, in case we were called from Test::Kit
+    my $kit = shift;
+    #print STDERR "Invoked from Test::Kit module $kit\n";
+
+    my $level;
+
+    my $callpkg;
+
+    # Find the caller of $kit, and import directly there.
+    for($level=0; 1; ++$level) {
+        $callpkg = caller($level);
+        last unless $callpkg;
+        last if $callpkg eq $kit;
+    } #for levels
+
+    if($callpkg && ($callpkg eq $kit)) {
+        ++$level;
+        $callpkg = caller($level);
+        return ($callpkg, $level) if $callpkg;
+    }
+
+    die "Could not find the module that invoked Test::Kit module $kit";
+} #_escapekit()
+
 =head2 _printtrace
 
 Print a full stack trace
@@ -337,9 +364,10 @@ sub _printtrace {
     print Dumper(\@callers), "\n";
 }
 
+# }}}2
 # }}}1
 
-# More docs {{{3
+# More docs, and $VERSION {{{3
 =head1 VARIABLES
 
 =head2 C<$TEST_NUMBER_OS>
@@ -411,11 +439,11 @@ L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-OnlySome>
 
 # }}}3
 
-our $VERSION = '0.000_003';
+our $VERSION = '0.000_004';
 
 =head1 VERSION
 
-Version 0.0.3-dev
+Version 0.0.4 (dev)
 
 =cut
 
